@@ -146,45 +146,6 @@ class LocalCached:
             return getattr(self.mc, name)(*args, **kwargs)
         return func
 
-class FakeMemcacheClient(object):
-    def __getattr__(self,*args,**kwargs):
-        def func(*args,**kwargs):
-            return None
-        return func
-    
-    def append(self,key,val):
-        return 0
-
-    def prepend(self,key,val):
-        return 0
-
-    def set(self, key, val, time=0):
-        return 1
-
-    def delete(self, key, time=0):
-        return 0
-
-    def get(self, key):
-        return None
-
-    def get_raw(self, key):
-        return None
-
-    def get_multi(self, keys):
-        return {}
-
-    def get_list(self, keys):
-        return [None] * len(keys)
-
-    def incr(self, key, val=1):
-        return 0
-
-    def decr(self, key, val=1):
-        return 0
-
-    def clear(self):
-        pass
-
 
 mc = None
 
@@ -193,6 +154,61 @@ def init_mc(memcached_addr=None,disable_local_cached=False):
     global mc
 
     if not memcached_addr:
+        import lrucache
+        class FakeMemcacheClient(object):
+            def __init__(self):
+                self.cache = LRUCache(4096)
+
+            def __getattr__(self,*args,**kwargs):
+                def func(*args,**kwargs):
+                    return None
+                return func
+            
+            def append(self,key,val):
+                return 0
+
+            def prepend(self,key,val):
+                return 0
+
+            def set(self, key, val, time=0):
+                self.cache[key]=val
+                return 1
+
+            def delete(self, key, time=0):
+                if key in self.cache:
+                    del self.cache[key]
+                return 0
+
+            def get(self, key):
+                if key in self.cache:
+                    return self.cache[key]
+                return None
+
+            def get_raw(self, key):
+                return None
+
+            def get_multi(self, keys):
+                return dict(self.get_list(keys))
+
+            def get_list(self, keys):
+                result = []
+                for key in keys:
+                    result.append(self.get(key))
+                return result
+
+            def incr(self, key, val=1):
+                if key in self.cache:
+                    self.cache[key]+=val
+                return 0
+
+            def decr(self, key, val=1):
+                if key in self.cache:
+                    self.cache[key]-=val
+                return 0
+
+            def clear(self):
+                pass
+
         mc = FakeMemcacheClient()
     else:
         import cmemcached
